import asyncio
from .functions05 import Configs
from ..exceptions import Qbitorcancel
#===================================================================

class TEngine:

    async def get01(cli, hid):
        moonus = cli.torrents_info(torrent_hashes=hid)[0]
        return moonus

#===================================================================

    async def get02(imog, cli, cid, hid):
        while True: #wait_for_metadata
            if cid not in Configs.DATA06:
                raise Qbitorcancel
            await asyncio.sleep(1)
            files = cli.torrents_files(torrent_hash=hid)
            if files:
                return files

#===================================================================

    async def get03(cid):
        append.Configs.DATA07(cid)
        while True:
            if cid not in Configs.DATA07:
                break

#===================================================================



appname = "qbited"
version = "0.0.1"

install = []

DATA01 = None
DATA02 = ['Natural Language :: English',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
          'Programming Language :: Python :: 3.13',
          'Programming Language :: Python :: 3.14',
         ]



from setuptools import setup, find_packages
from Qbited import appname, version, install, DATA01, DATA02

with open("README.md", "r") as o:
    description = o.read()
    
setup(
    name=appname,
    license='MIT',
    version=version,
    description='ㅤ',
    author='Clinton',
    classifiers=DATA02,
    author_email=DATA01,
    python_requires='~=3.10',
    packages=find_packages(),
    install_requires=install,
    long_description=description,
    keywords=['apps', 'python', 'extensions'],
    long_description_content_type="text/markdown")
